@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $superduper: decoder.c,v 1.11 2004/10/30 10:20:05 sam Exp $
+ * $superduper: decoder.c,v 1.12 2005/02/10 14:06:23 sam Exp $
  */
 #include <assert.h>
 #include <pthread.h>
@@ -123,9 +123,7 @@ write_output (struct mad_info_t *info, struct mad_pcm *pcm,
     return;
   mad_plugin.add_vis_pcm (mad_plugin.output->written_time (),
       FMT_S16_LE, MAD_NCHANNELS (header), olen, output);
-  if (info->stop)
-    return;
-  while (mad_plugin.output->buffer_free () < olen)
+  while (!info->stop && mad_plugin.output->buffer_free () < olen)
     usleep (10000);
   if (info->stop)
     return;
