@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: xmms-mad.c,v 1.14 2004/10/30 10:20:05 sam Exp $
+ * $Id: xmms-mad.c,v 1.15 2005/02/10 14:06:23 sam Exp $
  */
 #include "config.h"
 #include "xmms-mad.h"
@@ -166,7 +166,7 @@ xmmsmad_play_file (char *url)
   g_message ("playing %s", url);
 #endif /* DEBUG */
 
-  if (input_init (&info, url) == FALSE) 
+  if (input_init (&info, url) == FALSE)
     {
       g_message ("error initialising input");
       return;
@@ -181,12 +181,19 @@ xmmsmad_play_file (char *url)
     }
 
   decode_thread = g_malloc (sizeof (pthread_t));
-  if (decode_thread && pthread_create (decode_thread, 0, decode, (void *) &info))
+  if (!decode_thread)
+    {
+      g_message ("error creating decode thread");
+      return;
+    }
+
+  if (pthread_create (decode_thread, 0, decode, (void *) &info))
     {
       /* malloc succeded but pthread_create failed */
       g_message ("error creating decode thread");
       g_free (decode_thread);
       decode_thread = 0;
+      return;
     }
 }
 
